@@ -26,6 +26,11 @@ implementations.
 * [Feedback Transformer](transformers/feedback/index.html)
 * [Switch Transformer](transformers/switch/index.html)
 * [Fast Weights Transformer](transformers/fast_weights/index.html)
+* [FNet](transformers/fnet/index.html)
+* [Attention Free Transformer](transformers/aft/index.html)
+* [Masked Language Model](transformers/mlm/index.html)
+* [MLP-Mixer: An all-MLP Architecture for Vision](transformers/mlp_mixer/index.html)
+* [Pay Attention to MLPs (gMLP)](transformers/gmlp/index.html)
 
 #### ✨ [Recurrent Highway Networks](recurrent_highway_networks/index.html)
 
