@@ -57,6 +57,31 @@ It does single GPU training but we implement the concept of switching as describ
 
 This is an implementation of the paper
 [Linear Transformers Are Secretly Fast Weight Memory Systems in PyTorch](https://arxiv.org/abs/2102.11174).
+
+## [FNet: Mixing Tokens with Fourier Transforms](fnet/index.html)
+
+This is an implementation of the paper
+[FNet: Mixing Tokens with Fourier Transforms](https://arxiv.org/abs/2105.03824).
+
+## [Attention Free Transformer](aft/index.html)
+
+This is an implementation of the paper
+[An Attention Free Transformer](https://papers.labml.ai/paper/2105.14103).
+
+## [Masked Language Model](mlm/index.html)
+
+This is an implementation of Masked Language Model used for pre-training in paper
+[BERT: Pre-training of Deep Bidirectional Transformers for Language Understanding](https://arxiv.org/abs/1810.04805).
+
+## [MLP-Mixer: An all-MLP Architecture for Vision](mlp_mixer/index.html)
+
+This is an implementation of the paper
+[MLP-Mixer: An all-MLP Architecture for Vision](https://papers.labml.ai/paper/2105.01601).
+
+## [Pay Attention to MLPs (gMLP)](gmlp/index.html)
+
+This is an implementation of the paper
+[Pay Attention to MLPs](https://papers.labml.ai/paper/2105.08050).
 """
 
 from .configs import TransformerConfigs
